==> styled-components-0.1.5.tgz: package/lib/utils/test/flatten.test.js <==
'use strict';

var _expect = require('expect');

var _expect2 = _interopRequireDefault(_expect);

var _flatten = require('../flatten');

var _flatten2 = _interopRequireDefault(_flatten);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('flatten', function () {
  it('doesnt merge strings', function () {
    (0, _expect2.default)((0, _flatten2.default)(['foo', 'bar', 'baz'])).toEqual(['foo', 'bar', 'baz']);
  });
  it('drops nulls', function () {
    (0, _expect2.default)((0, _flatten2.default)(['foo', false, 'bar', undefined, 'baz', null])).toEqual(['foo', 'bar', 'baz']);
  });
  it('toStrings everything', function () {
    (0, _expect2.default)((0, _flatten2.default)([1, true])).toEqual(['1', 'true']);
  });
  it('hypenates objects', function () {
    var obj = {
      fontSize: '14px',
      WebkitFilter: 'blur(2px)'
    };
    var css = 'font-size: 14px; -webkit-filter: blur(2px);';
    (0, _expect2.default)((0, _flatten2.default)([obj])).toEqual([css]);
    (0, _expect2.default)((0, _flatten2.default)(['some:thing;', obj, 'something: else;'])).toEqual(['some:thing;', css, 'something: else;']);
  });
  it('flattens subarrays', function () {
    (0, _expect2.default)((0, _flatten2.default)([1, 2, [3, 4, 5], 'come:on;', 'lets:ride;'])).toEqual(['1', '2', '3', '4', '5', 'come:on;', 'lets:ride;']);
  });
  it('defers functions', function () {
    var func = function func() {
      return 'bar';
    };
    var funcWFunc = function funcWFunc() {
      return ['static', function (subfunc) {
        return subfunc ? 'bar' : 'baz';
      }];
    };
    (0, _expect2.default)((0, _flatten2.default)(['foo', func, 'baz'])).toEqual(['foo', func, 'baz']);
    (0, _expect2.default)((0, _flatten2.default)(['foo', funcWFunc, 'baz'])).toEqual(['foo', funcWFunc, 'baz']);
  });
  it('executes functions', function () {
    var func = function func() {
      return 'bar';
    };
    (0, _expect2.default)((0, _flatten2.default)(['foo', func, 'baz'], [true])).toEqual(['foo', 'bar', 'baz']);
  });
  it('passes values to function', function () {
    var func = function func(bool) {
      return bool ? 'bar' : 'baz';
    };
    (0, _expect2.default)((0, _flatten2.default)(['foo', func], [true])).toEqual(['foo', 'bar']);
    (0, _expect2.default)((0, _flatten2.default)(['foo', func], [false])).toEqual(['foo', 'baz']);
  });
  it('recursively calls functions', function () {
    var func = function func() {
      return ['static', function (subfunc) {
        return subfunc ? 'bar' : 'baz';
      }];
    };
    (0, _expect2.default)((0, _flatten2.default)(['foo', func], [true])).toEqual(['foo', 'static', 'bar']);
    (0, _expect2.default)((0, _flatten2.default)(['foo', func], [false])).toEqual(['foo', 'static', 'baz']);
  });
});

==> styled-components-0.1.6.tgz: package/lib/utils/test/flatten.test.js <==
'use strict';

var _expect = require('expect');

var _expect2 = _interopRequireDefault(_expect);

var _flatten = require('../flatten');

var _flatten2 = _interopRequireDefault(_flatten);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('flatten', function () {
  it('doesnt merge strings', function () {
    (0, _expect2.default)((0, _flatten2.default)(['foo', 'bar', 'baz'])).toEqual(['foo', 'bar', 'baz']);
  });
  it('drops nulls', function () {
    (0, _expect2.default)((0, _flatten2.default)(['foo', false, 'bar', undefined, 'baz', null])).toEqual(['foo', 'bar', 'baz']);
  });
  it('toStrings everything', function () {
    (0, _expect2.default)((0, _flatten2.default)([1, true])).toEqual(['1', 'true']);
  });
  it('hypenates objects', function () {
    var obj = {
      fontSize: '14px',
      WebkitFilter: 'blur(2px)'
    };
    var css = 'font-size: 14px; -webkit-filter: blur(2px);';
    (0, _expect2.default)((0, _flatten2.default)([obj])).toEqual([css]);
    (0, _expect2.default)((0, _flatten2.default)(['some:thing;', obj, 'something: else;'])).toEqual(['some:thing;', css, 'something: else;']);
  });
  it('flattens subarrays', function () {
    (0, _expect2.default)((0, _flatten2.default)([1, 2, [3, 4, 5], 'come:on;', 'lets:ride;'])).toEqual(['1', '2', '3', '4', '5', 'come:on;', 'lets:ride;']);
  });
  it('defers functions', function () {
    var func = function func() {
      return 'bar';
    };
    var funcWFunc = function funcWFunc() {
      return ['static', function (subfunc) {
        return subfunc ? 'bar' : 'baz';
      }];
    };
    (0, _expect2.default)((0, _flatten2.default)(['foo', func, 'baz'])).toEqual(['foo', func, 'baz']);
    (0, _expect2.default)((0, _flatten2.default)(['foo', funcWFunc, 'baz'])).toEqual(['foo', funcWFunc, 'baz']);
  });
  it('executes functions', function () {
    var func = function func() {
      return 'bar';
    };
    (0, _expect2.default)((0, _flatten2.default)(['foo', func, 'baz'], { bool: true })).toEqual(['foo', 'bar', 'baz']);
  });
  it('passes values to function', function () {
    var func = function func(_ref) {
      var bool = _ref.bool;
      return bool ? 'bar' : 'baz';
    };
    (0, _expect2.default)((0, _flatten2.default)(['foo', func], { bool: true })).toEqual(['foo', 'bar']);
    (0, _expect2.default)((0, _flatten2.default)(['foo', func], { bool: false })).toEqual(['foo', 'baz']);
  });
  it('recursively calls functions', function () {
    var func = function func() {
      return ['static', function (_ref2) {
        var bool = _ref2.bool;
        return bool ? 'bar' : 'baz';
      }];
    };
    (0, _expect2.default)((0, _flatten2.default)(['foo', func], { bool: true })).toEqual(['foo', 'static', 'bar']);
    (0, _expect2.default)((0, _flatten2.default)(['foo', func], { bool: false })).toEqual(['foo', 'static', 'baz']);
  });
});
